# 1.4.1

- Fixed a bug with json load encoding issue

# 1.4.0

- Added custom `layers` support for lambda functions
- Fixed a bug with empty `streams` resources
- Added `envvars` (global environment variables for functions)
- Added `tags` support to the resources.yaml file

# 1.3.0

- Added multibucket stream support
- Added conditional resources support
- Added `inspect schema` command to validate the resources.yaml file
- Added `inspect cloud` command to inspect required cloud resources

# 1.2.0

- Added `extra-imports` support to Prismarine
- Added `version` command

## 1.1.0

- Prismarine support
- Added `delete` command
- Added `cleanup` command
- Added `inspect` command

## 1.0.0

- First published version
